@@ -5,6 +5,7 @@ from enum import Enum
 
 from cctk import File, Molecule, ConformationalEnsemble, OneIndexedArray
 from cctk.helper_functions import get_symbol, get_number, get_corrected_free_energy
+import cctk
 
 import cctk.parse_gaussian as parse
 
@@ -138,7 +139,7 @@ class GaussianFile(File):
         return f"GaussianFile (title=\"{str(self.title)}\", {len(self.ensemble)} entries in Ensemble)"
 
     @classmethod
-    def write_molecule_to_file(cls, filename, molecule, route_card, link0={"mem": "32GB", "nprocshared": 16}, footer=None, title="title", append=False, print_symbol=False):
+    def write_molecule_to_file(cls, filename, molecule, route_card, link0={"mem": "32GB", "nprocshared": 16}, footer=None, title="title", append=False, print_symbol=False, point_charges=None):
         """
         Write a ``.gjf`` file using the given molecule.
 
@@ -161,6 +162,11 @@ class GaussianFile(File):
         if not re.match(r"^#p", route_card):
             warnings.warn(f"route card doesn't start with #p: {route_card}")
 
+        if point_charges is not None:
+            assert isinstance(point_charges, list), "point_charges must be list"
+            assert all([isinstance(pc, cctk.PointCharge) for pc in point_charges]), "point_charges must be list of point charges"
+            assert re.search(r"charge", route_card, flags=re.IGNORECASE), "charge must be in route_card if point_charges are present"
+
         #### generate the text
         text = ""
         if append:
@@ -185,6 +191,11 @@ class GaussianFile(File):
         if footer is not None:
             text += f"{footer.strip()}\n\n"
 
+        if point_charges is not None:
+            for point_charge in point_charges:
+                text += f"{point_charge.coordinates[0]:>13.8f} {point_charge.coordinates[1]:>13.8f} {point_charge.coordinates[2]:>13.8f} {point_charge.charge:.5f}\n"
+            text += "\n"
+
         #### write the file
         if append:
             super().append_to_file(filename, text)
@@ -699,7 +710,7 @@ class GaussianFile(File):
             raise ValueError(f"adding basis set {name} from basis set exchange failed!\n{e}")
 
     @classmethod
-    def read_file(cls, filename, return_lines=False, extended_opt_info=False):
+    def read_file(cls, filename, return_lines=False, extended_opt_info=False, fail_silently=True):
 #    def read_fast(cls, filename, return_lines=False, extended_opt_info=False):
         """
         Reads a Gaussian``.out`` or ``.gjf`` file and populates the attributes accordingly.
@@ -714,6 +725,8 @@ class GaussianFile(File):
             return_lines (Bool): whether the lines of the file should be returned
             extended_opt_info (Bool): if full parameters about each opt step should be collected
                 (by default, only ``rms_displacement`` and ``rms_force`` are collected)
+            fail_silently (Bool): if true, files that fail validation will just be omitted and parsing will continue.
+                useful for monitoring jobs which are in-progress and may not have all properties written.
         Returns:
             ``GaussianFile`` object (or list of ``GaussianFile`` objects for Link1 files)
             (optional) the lines of the file (or list of lines of file for Link1 files) as Lines object
@@ -725,7 +738,9 @@ class GaussianFile(File):
         files = []
 
         for link1idx, lines in enumerate(link1_lines):
-            files.append(parse.read_file_fast(lines, filename, link1idx, extended_opt_info=extended_opt_info))
+            current_file = parse.read_file_fast(lines, filename, link1idx, extended_opt_info=extended_opt_info, fail_silently=fail_silently)
+            if current_file is not None:
+                files.append(current_file)
 
         if return_lines:
             link1_lines = parse.split_link1(filename)
