@@ -9,6 +9,7 @@ import cctk
 from cctk.helper_functions import (
     get_symbol,
     get_number,
+    get_avg_mass,
     compute_rotation_matrix,
     compute_distance_between,
     compute_angle_between,
@@ -1664,7 +1665,7 @@ class Molecule:
         energy = opt.get_energy(self, nprocs=nprocs)
         return energy
 
-    def csearch(self, nprocs=1, constraints=[], logfile=None, noncovalent=False, use_tempdir=True):
+    def csearch(self, nprocs=1, constraints=[], logfile=None, noncovalent=False, use_tempdir=True, gfn=2, additional_flags=None):
         """
         Optimize molecule at the GFN2-xtb level of theory.
 
@@ -1674,13 +1675,15 @@ class Molecule:
             noncovalent (bool): whether or not to use non-covalent settings
             logfile (str): file to write ongoing ``crest`` output to
             use_tempdir (bool): write intermediate files to hidden directory (as opposed to current directory)
+            gfn (int or ``ff``): level of theory, either 1, 2, or ``ff``
+            additional_flags (str): additional flags for command line
 
         Returns
             ConformationalEnsemble
         """
         import cctk.optimize as opt
         assert isinstance(nprocs, int), "nprocs must be int!"
-        return opt.csearch(molecule=self, nprocs=nprocs, constraints=constraints, noncovalent=noncovalent, logfile=logfile, use_tempdir=use_tempdir)
+        return opt.csearch(molecule=self, nprocs=nprocs, constraints=constraints, noncovalent=noncovalent, logfile=logfile, use_tempdir=use_tempdir, gfn=gfn, additional_flags=additional_flags)
 
     def num_neighbors_by_atom(self):
         """
@@ -1828,3 +1831,45 @@ class Molecule:
                 energy += Q[i][j] / R[i][j]
 
         return energy * 627.509 # convert to kcal/mol
+
+    def center_of_mass(self):
+        """
+        Returns the center-of-mass of the molecule, as a ``np.array``.
+        """
+        masses = cctk.OneIndexedArray([get_avg_mass(z) for z in self.atomic_numbers]).reshape(-1,1)
+        return np.sum(masses * self.geometry, axis=0) / np.sum(masses)
+
+    def principal_axes_of_rotation(self):
+        """
+        Compute principal axes of rotation and corresponding moments of inertia.
+
+        See Jprogdyn, RotationalBoltzmann, lines 48–115.
+
+        Returns:
+            moments of intertia (3-element np.array) - some may be zero
+            axes of rotation (3 x 3 np.array)
+        """
+        # move everything to the center of mass (on a copy, let's not get too crazy here)
+        com = self.center_of_mass()
+        positions = copy.deepcopy(self.geometry.view(np.ndarray))
+        positions += -1 * com
+
+        masses = np.array([get_avg_mass(z) for z in self.atomic_numbers]).reshape(-1,1)
+        np.testing.assert_allclose(np.sum(masses * positions, axis=0) / np.sum(masses), 0, atol=0.00001)
+
+        # build up mass moment of inertia tensor
+        Ixx, Ixy, Ixz, Iyy, Iyz, Izz = 0, 0, 0, 0, 0, 0
+        for mass, position in zip(masses, positions):
+            Ixx += mass * (position[2]*position[2] + position[1]*position[1])
+            Iyy += mass * (position[0]*position[0] + position[2]*position[2])
+            Izz += mass * (position[0]*position[0] + position[1]*position[1])
+            Ixy -= mass * position[0] * position[1]
+            Ixz -= mass * position[0] * position[2]
+            Iyz -= mass * position[1] * position[2]
+
+        I = np.array([[Ixx, Ixy, Ixz], [Ixy, Iyy, Iyz], [Ixz, Iyz, Izz]]).reshape(3,3)
+
+        # now we do an eigendecomposition on that tensor
+        return np.linalg.eigh(I)
+
+
